﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.SceneManagement;

public class PlayerMovement : MonoBehaviour
{
    private Rigidbody MyRB;
    private Animator MyAnim;
    public bool CanMove = true;
    [Header("Movement Varijables")]
    public float MoveSpeed;
    public float JumpHeight;
    private bool IsGrounded;
    [Header("Ground Checker")]
    public Transform GroundChecker;
    public float GroundCheckRadius;
    public LayerMask GroundLayer;
    [Header("Interaction Checker")]
    public float InteractableCheckerRadius;
    public LayerMask InteractableLayer;
    private GameObject InteractableObject;
    public float InteractionDistance;


    private void Start()
    {
        MyRB = GetComponent<Rigidbody>();
        MyAnim = GetComponent<Animator>();
    }

    private void Update()
    {
        //MyAnim.SetBool("Interacting", CanMove);

        

        if (PauseManager.IsPaused == false)
        {
            CheckIfGrounded();
            if (InteractableObject == null)
            {
                CheckIfInteractiable();
            }
            else
            {
                if (Vector3.Distance(transform.position, InteractableObject.transform.position) <= InteractionDistance)
                {
                    InteractionCheck();
                }
                else
                {
                    InteractableObject = null;
                }
            }
        }
    }

    private void FixedUpdate()
    {
        Move();
        Jump();
    }


    private void Move()
    {
        if (this.gameObject.name == "Player1")
        {
            if (Input.GetKey(KeyCode.A) && CanMove)
            {
                MyRB.MovePosition(transform.position + (Vector3.left * MoveSpeed * Time.deltaTime));
                this.transform.rotation = Quaternion.Euler(new Vector3(0, -90, 0));
                if (MyAnim != null)
                {
                    MyAnim.SetFloat("Speed", 0.2f);
                }
            }
            else if (Input.GetKey(KeyCode.D) && CanMove)
            {
                MyRB.MovePosition(transform.position + (Vector3.right * MoveSpeed * Time.deltaTime));
                this.transform.rotation = Quaternion.Euler(new Vector3(0, 90, 0));
                if (MyAnim != null)
                {
                    MyAnim.SetFloat("Speed", 0.2f);
                }
            }
            else
            {
                if (MyAnim != null)
                {
                    MyAnim.SetFloat("Speed", 0f);
                }
            }
        }
        else if(this.gameObject.name == "Player2")
        {
            if (Input.GetKey(KeyCode.LeftArrow) && CanMove)
            {
                MyRB.MovePosition(transform.position + (Vector3.left * MoveSpeed * Time.deltaTime));
                this.transform.rotation = Quaternion.Euler(new Vector3(0, -90, 0));
                if (MyAnim != null)
                {
                    MyAnim.SetFloat("Speed", 0.2f);
                }
            }
            else if (Input.GetKey(KeyCode.RightArrow) && CanMove)
            {
                MyRB.MovePosition(transform.position + (Vector3.right * MoveSpeed * Time.deltaTime));
                this.transform.rotation = Quaternion.Euler(new Vector3(0, 90, 0));
                if (MyAnim != null)
                {
                    MyAnim.SetFloat("Speed", 0.2f);
                }
            }
            else
            {
                if (MyAnim != null)
                {
                    MyAnim.SetFloat("Speed", 0f);
                }
            }
        }
    }

    private void Jump()
    {
        if (this.gameObject.name == "Player1")
        {
            if (Input.GetKey(KeyCode.W) && IsGrounded && CanMove)
            {
                MyRB.velocity = new Vector3(0, JumpHeight, 0);
                if(MyAnim != null)
                {
                    MyAnim.SetTrigger("Jump");
                }
            }
        }
        else if(this.gameObject.name == "Player2")
        {
            if (Input.GetKey(KeyCode.UpArrow) && IsGrounded && CanMove)
            {
                MyRB.velocity = new Vector3(0, JumpHeight, 0);
                if (MyAnim != null)
                {
                    MyAnim.SetTrigger("Jump");
                }
            }
        }
    }

    void CheckIfGrounded()
    {
        IsGrounded = Physics.CheckSphere(GroundChecker.position, GroundCheckRadius, GroundLayer);
    }

    void CheckIfInteractiable()
    {
        Collider[] colliders = Physics.OverlapSphere(transform.position, InteractableCheckerRadius, InteractableLayer);
        if (colliders.Length > 0)
        {
            for (int i = 0; i < colliders.Length; i++)
            {
                if (colliders[i].CompareTag("Lever"))
                {
                    InteractableObject = colliders[i].gameObject;
                }
            }
        }else if(colliders.Length == 0)
        {
            InteractableObject = null;
        }
    }

    void InteractionCheck()
    {
        if (this.gameObject.name == "Player1")
        {
            if (Input.GetKeyDown(KeyCode.E))
            {
                MyAnim.SetTrigger("Interact");

                if (InteractableObject.CompareTag("Lever"))
                {
                    if (InteractableObject.GetComponent<LeverPuzzle>().IsInteracted == false)
                    {
                        InteractableObject.GetComponent<LeverPuzzle>().BeingInteracted(this.gameObject);
                        InteractableObject = null;
                    }
                    else
                    {
                        //Debug.Log("this object was already interacted with");
                    }

                }
            }
        }
        else if(this.gameObject.name == "Player2")
        {
            if (Input.GetKeyDown(KeyCode.Return))
            {
                MyAnim.SetTrigger("Interact");

                if (InteractableObject.CompareTag("Lever"))
                {
                    if (InteractableObject.GetComponent<LeverPuzzle>().IsInteracted == false)
                    {
                        InteractableObject.GetComponent<LeverPuzzle>().BeingInteracted(this.gameObject);
                        InteractableObject = null;
                    }
                    else
                    {
                        //Debug.Log("this object was already interacted with");
                    }

                }
            }
        }
      }

    public void Die()
    {
        SceneManager.LoadScene(SceneManager.GetActiveScene().buildIndex);
    }
}
